@@ -1,6 +1,6 @@
-__version__ = '0.0.505'
+__version__ = '0.4.7'
 
-from .tremolo import Tremolo  # noqa: E402
+from .tremolo import Tremolo, Tremolo as Application  # noqa: E402,F401
 from . import exceptions  # noqa: E402,F401
 
 
