@@ -1,6 +1,6 @@
 # Copyright (c) 2023 nggit
 
-from .lib.http_exception import (  # noqa: F401
+from .lib.http_exceptions import (  # noqa: F401
     TremoloException,
     HTTPException,
     BadRequest,
@@ -9,10 +9,11 @@ from .lib.http_exception import (  # noqa: F401
     NotFound,
     MethodNotAllowed,
     RequestTimeout,
+    PreconditionFailed,
     PayloadTooLarge,
-    URITooLong,
     RangeNotSatisfiable,
     ExpectationFailed,
+    TooManyRequests,
     InternalServerError,
     ServiceUnavailable,
     WebSocketException,
