@@ -1,6 +1,6 @@
 # Copyright (c) 2023 nggit
 
-import traceback
+from traceback import TracebackException
 
 from .exceptions import BadRequest
 from .utils import html_escape
@@ -14,7 +14,7 @@ async def error_400(**_):
     raise BadRequest
 
 
-async def error_404(request=None, **_):
+async def error_404(request, globals, **_):
     yield (
         b'<!DOCTYPE html><html lang="en"><head><meta name="viewport" '
         b'content="width=device-width, initial-scale=1.0" />'
@@ -27,14 +27,22 @@ async def error_404(request=None, **_):
            html_escape(request.path))
     yield (
         b'<address title="Powered by Tremolo">%s</address>'
-        b'</body></html>' % request.protocol.options['server_info']['name']
+        b'</body></html>' % globals.info['server_name']
     )
 
 
-async def error_500(request=None, exc=None, **_):
+async def error_405(**_):
+    return b'Method Not Allowed'
+
+
+async def error_500(request, exc=None, **_):
+    if exc is None or request.protocol is None:
+        return
+
     if request.protocol.options['debug']:
+        te = TracebackException.from_exception(exc)
         return '<ul><li>%s</li></ul>' % '</li><li>'.join(
-            traceback.TracebackException.from_exception(exc).format()
+            html_escape(line) for line in te.format()
         )
 
     return str(exc)
