@@ -2,47 +2,27 @@
 
 import asyncio
 
-from concurrent.futures import ThreadPoolExecutor
-
 
 class ServerLock:
-    def __init__(self, locks, name=0, timeout=30, loop=None, executors=None):
-        try:
-            self.name = name % len(locks)
-        except ZeroDivisionError:
-            return
-
+    def __init__(self, locks, executor, name=0, timeout=30, loop=None):
         self.locks = locks
+        self.name = name % len(locks)
+        self._executor = executor
         self._timeout = timeout
+        self._loop = loop or asyncio.get_event_loop()
 
-        if loop is None:
-            loop = asyncio.get_event_loop()
-
-        self._loop = loop
-
-        if executors is None:
-            executors = {}
-
-        self._executors = executors
-
-        if self.name not in executors:
-            self._executors[self.name] = ThreadPoolExecutor(max_workers=1)
-
-    def __call__(self, name=0, timeout=None):
+    def __call__(self, name=0, *, timeout=None):
         if timeout is None:
             timeout = self._timeout
 
         return self.__class__(self.locks,
+                              self._executor,
                               name=name,
                               timeout=timeout,
-                              loop=self._loop,
-                              executors=self._executors)
+                              loop=self._loop)
 
     async def __aenter__(self):
-        try:
-            await self.acquire()
-        except TimeoutError:
-            self.release()
+        await self.acquire()
 
     async def __aexit__(self, exc_type, exc, tb):
         self.release()
@@ -51,17 +31,15 @@ class ServerLock:
         if timeout is None:
             timeout = self._timeout
 
-        fut = self._loop.run_in_executor(
-            self._executors[self.name],
-            self.locks[self.name].acquire, True, timeout)
-
+        fut = self._executor.submit(self.locks[self.name].acquire,
+                                    args=(True, timeout),
+                                    name=self.name)
         timer = self._loop.call_at(self._loop.time() + timeout, fut.cancel)
-        result = False
 
         try:
             result = await fut
         except asyncio.CancelledError:
-            pass
+            result = False
         finally:
             timer.cancel()
 
